package com.ruoyi.brewery.mapper;

import java.util.List;
import com.ruoyi.brewery.domain.WyBrewerySharePlan;

/**
 * 品牌方分享方案Mapper接口
 * 
 * @author ruoyi
 * @date 2025-02-23
 */
public interface WyBrewerySharePlanMapper 
{
    /**
     * 查询品牌方分享方案
     * 
     * @param id 品牌方分享方案主键
     * @return 品牌方分享方案
     */
    public WyBrewerySharePlan selectWyBrewerySharePlanById(Long id);

    /**
     * 查询品牌方分享方案列表
     * 
     * @param wyBrewerySharePlan 品牌方分享方案
     * @return 品牌方分享方案集合
     */
    public List<WyBrewerySharePlan> selectWyBrewerySharePlanList(WyBrewerySharePlan wyBrewerySharePlan);

    /**
     * 新增品牌方分享方案
     * 
     * @param wyBrewerySharePlan 品牌方分享方案
     * @return 结果
     */
    public int insertWyBrewerySharePlan(WyBrewerySharePlan wyBrewerySharePlan);

    /**
     * 修改品牌方分享方案
     * 
     * @param wyBrewerySharePlan 品牌方分享方案
     * @return 结果
     */
    public int updateWyBrewerySharePlan(WyBrewerySharePlan wyBrewerySharePlan);

    /**
     * 删除品牌方分享方案
     * 
     * @param id 品牌方分享方案主键
     * @return 结果
     */
    public int deleteWyBrewerySharePlanById(Long id);

    /**
     * 批量删除品牌方分享方案
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteWyBrewerySharePlanByIds(Long[] ids);
}
